import React from 'react';
import { SortableHandle } from 'react-sortable-hoc';
import { createStyledComponent } from '@cloudflare/style-container';
import { Span } from '@cloudflare/elements';
import DragHandleIcon from './DragHandleIcon';

type HandleProps = {
  sorting?: boolean;
};

const Handle = createStyledComponent(({ sorting }: HandleProps) => ({
  whiteSpace: 'nowrap',
  cursor: 'grab',
  opacity: sorting ? 0.5 : 1,
  pointerEvents: sorting ? 'none' : undefined,
  transition: 'opacity 0.2s linear',
  display: 'flex',
  px: 1,
  mr: 1
}));

type Props = {
  order?: React.ReactNode;
  disabled?: boolean;
  sorting?: boolean;
};

export default SortableHandle(({ order, disabled, sorting }: Props) => (
  <Handle className="cf-drag-handle" sorting={sorting}>
    {!disabled && (
      <Span minWidth={10}>
        <DragHandleIcon />
      </Span>
    )}
    {order && <Span ml={2}>{order}</Span>}
  </Handle>
));
